==> tuia-client-0.8.49-sources.jar: cn/com/tuia/advert/enums/ActivityTypeEnum.java <==
package cn.com.tuia.advert.enums;

/**
 * ClassName: ActivityTypeEnum <br/>
 * Function: 活动类型枚举. <br/>
 * date: 2018年12月18日 下午7:09:22 <br/>
 *
 * @author chencheng
 * @version
 * @since JDK 1.8
 */
public enum ActivityTypeEnum {

    PLUGIN_ACTIVITY_TYPE(1, "1", "配置包插件活动"),

    ACT_ACTIVITY_TYPE(2, "2", "活动工具"),

    DIRECT_PAGE_ACTIVITY_TYPE(3, "3", "直投页"),
    
    SHOW_ACTIVITY_TYPE(4, "4", "展示广告"),
    
    FLOAT_ACTIVITY_TYPE(5, "5", "浮标"),
    
    ENCOURAGE_ACTIVITY_TYPE(6, "6", "增值广告"),
    
    DIRECT_LAND_ACTIVITY_TYPE(7, "7", "活动直投落地页"),

    VEDIO_ADVERT_ACTIVITY_TYPE(8,"8","激励视屏");

    private Integer code;

    private String  codeStr;

    private String  desc;

    private ActivityTypeEnum(Integer code, String codeStr, String desc) {
        this.code = code;
        this.codeStr = codeStr;
        this.desc = desc;
    }

    /**
     * code.
     *
     * @return the code
     * @since JDK 1.8
     */
    public Integer getCode() {
        return code;
    }

    /**
     * code.
     *
     * @param code the code to set
     * @since JDK 1.8
     */
    public void setCode(Integer code) {
        this.code = code;
    }

    /**
     * codeStr.
     *
     * @return the codeStr
     * @since JDK 1.8
     */
    public String getCodeStr() {
        return codeStr;
    }

    /**
     * codeStr.
     *
     * @param codeStr the codeStr to set
     * @since JDK 1.8
     */
    public void setCodeStr(String codeStr) {
        this.codeStr = codeStr;
    }

    /**
     * desc.
     *
     * @return the desc
     * @since JDK 1.8
     */
    public String getDesc() {
        return desc;
    }

    /**
     * desc.
     *
     * @param desc the desc to set
     * @since JDK 1.8
     */
    public void setDesc(String desc) {
        this.desc = desc;
    }

}

==> tuia-client-0.9.43-20210203.033108-1-sources.jar: cn/com/tuia/advert/enums/ActivityTypeEnum.java <==
package cn.com.tuia.advert.enums;

/**
 * ClassName: ActivityTypeEnum <br/>
 * Function: 活动类型枚举. <br/>
 * date: 2018年12月18日 下午7:09:22 <br/>
 *
 * @author chencheng
 * @version
 * @since JDK 1.8
 */
public enum ActivityTypeEnum {

    PLUGIN_ACTIVITY_TYPE(1, "1", "配置包插件活动"),

    ACT_ACTIVITY_TYPE(2, "2", "活动工具"),

    DIRECT_PAGE_ACTIVITY_TYPE(3, "3", "直投页"),
    
    SHOW_ACTIVITY_TYPE(4, "4", "展示广告"),
    
    FLOAT_ACTIVITY_TYPE(5, "5", "浮标"),
    
    ENCOURAGE_ACTIVITY_TYPE(6, "6", "增值广告"),
    
    DIRECT_LAND_ACTIVITY_TYPE(7, "7", "活动直投落地页"),

    NEW_ACTIVITY_DIRECT_TYPE(8,"8","创新直投"),

    NEW_VEDIO_ADVERT_ACTIVITY_TYPE(9,"9","新激励视屏"),

    ENC_ACTIVITY_TYPE(10, "10", "增值"),

    DP_ADVERT_ACTIVITY_TYPE(11,"11","dp广告");


    private Integer code;

    private String  codeStr;

    private String  desc;

    private ActivityTypeEnum(Integer code, String codeStr, String desc) {
        this.code = code;
        this.codeStr = codeStr;
        this.desc = desc;
    }

    /**
     * code.
     *
     * @return the code
     * @since JDK 1.8
     */
    public Integer getCode() {
        return code;
    }

    /**
     * code.
     *
     * @param code the code to set
     * @since JDK 1.8
     */
    public void setCode(Integer code) {
        this.code = code;
    }

    /**
     * codeStr.
     *
     * @return the codeStr
     * @since JDK 1.8
     */
    public String getCodeStr() {
        return codeStr;
    }

    /**
     * codeStr.
     *
     * @param codeStr the codeStr to set
     * @since JDK 1.8
     */
    public void setCodeStr(String codeStr) {
        this.codeStr = codeStr;
    }

    /**
     * desc.
     *
     * @return the desc
     * @since JDK 1.8
     */
    public String getDesc() {
        return desc;
    }

    /**
     * desc.
     *
     * @param desc the desc to set
     * @since JDK 1.8
     */
    public void setDesc(String desc) {
        this.desc = desc;
    }

}
